@@ -14,3 +14,7 @@ from imagen_pytorch.configs import UnetConfig, ImagenConfig, ElucidatedImagenCon
 # utils
 
 from imagen_pytorch.utils import load_imagen_from_checkpoint
+
+# video
+
+from imagen_pytorch.imagen_video import Unet3D
